# Description

Please include a summary of the changes and the related issue. Please also include relevant motivation and context. List any dependencies that are required for this change.

Fixes # (issue)

## Type of change

Please delete options that are not relevant.

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] This change requires a documentation update

## Checklist:

Before submitting your PR, please review the following checklist:

### General
- [ ] I have performed a self-review of my code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] Any dependent changes have been merged and published
- [ ] I have checked my code and corrected any misspellings

### Testing
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] I have tested this code in development environment
- [ ] I have tested edge cases and error conditions

### Security
- [ ] My code follows the project's security guidelines
- [ ] I have conducted a security impact assessment of my changes
- [ ] I have verified no sensitive information is exposed

### Performance
- [ ] I have verified my changes don't introduce performance regressions
- [ ] I have optimized any resource-intensive operations
- [ ] I have considered the impact on system resources

### Documentation
- [ ] I have updated the README.md (if applicable)
- [ ] I have updated the API documentation (if applicable)
- [ ] I have updated architecture docs (if applicable)
- [ ] I have added JSDoc/comments for all new code

### Dependencies
- [ ] I have updated the dependency list (if applicable)
- [ ] I have checked for and resolved any dependency conflicts
- [ ] I have verified compatibility with existing dependencies

### Compatibility
- [ ] My changes are backward compatible
- [ ] I have tested with different LLM providers
- [ ] I have tested with different configurations
- [ ] I have verified Docker compatibility

### Code Quality
- [ ] My code follows the project's style guidelines
- [ ] I have run linting tools and fixed any issues
- [ ] I have maintained or improved code coverage
- [ ] I have followed SOLID principles

## Screenshots/Videos

If applicable, add screenshots or videos to help explain your changes.

## Additional Notes

Add any other context about the PR here.

## Linked Issues

- Resolves #(issue number)
- Related to #(issue number)
